@@ -1,6 +1,6 @@
 /* 
  *
- * Copyright 2007,2008 Johannes Hofmann <Johannes.Hofmann@gmx.de>
+ * Copyright 2007-2009 Johannes Hofmann <Johannes.Hofmann@gmx.de>
  *
  * This software may be used and distributed according to the terms
  * of the GNU General Public License, incorporated herein by reference.
@@ -14,7 +14,7 @@
 #include <dirent.h>
 #include <errno.h>
 #include <libgen.h>
-#include <strings.h>
+#include <string.h>
 #include <stdlib.h>
 #include <readline/readline.h>
 #include <readline/history.h>
