@@ -21,7 +21,7 @@ pexecvp(const char *file, char *const argv[], pid_t *pid, char *type) {
 		return NULL;
 	}
 
-	*pid = vfork();
+	*pid = fork();
 
 	if (*pid == -1) {
 		perror("vfork");
@@ -46,7 +46,7 @@ pexecvp(const char *file, char *const argv[], pid_t *pid, char *type) {
 		}
 
 		execvp(file, argv);
-		_exit(127);
+		exit(127);
 	} else {
 		/* parent */ 
 		if (*type == 'r') {
